#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of CIHP."""

from tensorbay.opendataset.CIHP.loader import CIHP

__all__ = ["CIHP"]
